summaryrefslogtreecommitdiff
path: root/lib/gnutls_db.c
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2001-12-16 10:27:45 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2001-12-16 10:27:45 +0000
commita714fccfe5883f87e42d37dbc2ff783ccc168f5a (patch)
tree5a34667e3009dea529b8496649640bf7924dcf4e /lib/gnutls_db.c
parent94fb0cf9d16452af8ee521e565e033fcf91ea64d (diff)
downloadgnutls-a714fccfe5883f87e42d37dbc2ff783ccc168f5a.tar.gz
changed function names
Diffstat (limited to 'lib/gnutls_db.c')
-rw-r--r--lib/gnutls_db.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/gnutls_db.c b/lib/gnutls_db.c
index becb38287d..234325edaf 100644
--- a/lib/gnutls_db.c
+++ b/lib/gnutls_db.c
@@ -118,14 +118,14 @@ void* gnutls_db_get_ptr( GNUTLS_STATE state) {
}
/**
* gnutls_set_cache_expiration - Sets the expiration time for resumed sessions.
* @state: is a &GNUTLS_STATE structure.
* @seconds: is the number of seconds.
*
* Sets the expiration time for resumed sessions. The default is 3600 (one hour)
* at the time writing this.
**/
-void gnutls_set_cache_expiration( GNUTLS_STATE state, int seconds) {
+void gnutls_db_set_cache_expiration( GNUTLS_STATE state, int seconds) {
state->gnutls_internals.expire_time = seconds;
}
@@ -118,14 +118,14 @@ void* gnutls_db_get_ptr( GNUTLS_STATE state) {
}
/**
- * gnutls_set_cache_expiration - Sets the expiration time for resumed sessions.
+ * gnutls_db_set_cache_expiration - Sets the expiration time for resumed sessions.
* @state: is a &GNUTLS_STATE structure.
* @seconds: is the number of seconds.